@@ -23,6 +23,7 @@ from os.path import exists as path_exists
 
 import pprint
 import sys
+import socket
 import subprocess
 import tempfile
 import time
@@ -50,8 +51,8 @@ class ErrorExit(Exception):
 
 def yaml_dump(value):
     if optimized:
-        return _dump(value, Dumper=CSafeDumper)
-    return _dump(value)
+        return _dump(value, Dumper=CSafeDumper, default_flow_style=False)
+    return _dump(value, default_flow_style=False)
 
 
 def yaml_load(value):
@@ -315,7 +316,7 @@ class Endpoint(object):
         self.ep = ep
         self.name = None
         if ":" in self.ep:
-            self.service, name = self.ep.split(":")
+            self.service, self.name = self.ep.split(":")
         else:
             self.service = ep
 
@@ -739,7 +740,7 @@ class Deployment(object):
                 if not ep.service in services:
                     self.log.error(
                         "Invalid relation in config, service %s not found, rel %s" % (
-                        ep.name, "%s <-> %s" % (e_a, e_b)))
+                        ep.service, "%s <-> %s" % (e_a, e_b)))
 
     def save(self, path):
         with open(path, "w") as fh:
@@ -767,7 +768,7 @@ class Environment(object):
         while True:
             try:
                 self.client = EnvironmentClient(self.api_endpoint)
-            except Exception, e:
+            except socket.error, e:
                 if e.errno != errno.ETIMEDOUT:
                     raise
                 continue
@@ -811,10 +812,10 @@ class Environment(object):
         with temp_file() as fh:
             if config:
                 fh.write(yaml_dump(config))
+                fh.flush()
                 params.extend(["--config", fh.name])
             if constraints:
                 params.extend(['--constraints', constraints])
-                #print 'constraints', constraints
             if num_units != 1:
                 params.extend(["--num-units", str(num_units)])
             if charm_url.startswith('local'):
